package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````@!<``#0```"(D0````(`!30`(``)
M`"@`&P`:``$``'#,C```S(P``,R,```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``$P``
M`!,````$`````0````$```````````````````#8C```V(P```4`````$```
M`0```+R-``"\G0``O)T``(P"``"@`@``!@`````0```"````Q(T``,2=``#$
MG0``"`$```@!```&````!`````0```!H`0``:`$``&@!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO(T`
M`+R=``"\G0``1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!0````#````1TY5`'Q)#T0TGI?@&4M%)>*8T3Z1K>Y&!````!`````!
M````1TY5```````#`````@`````````1````2P````@````(`````9`0!"5`
M!(`H@``%H(90A("!``(+*`2,.(`208H```A+````3````$\```!3````5```
M`%T```!>````7P````````!A````8@```&,```!D````90```&@`````````
M``````&O-.ANQ=\?SMY'+6M_FGPNQ9NV=E0\E"#_Y`[59-1\V7%8'.)'Q@%"
M^M>'K$OCP+KCDGQ8[Y=YPN4_+/JA;&"R`8MOF4_#FVL)0]9GK\QF0D75[(D'
M<-,S8MOM%8PES`TZEPM_J9R;OMI7&^"G`@IK&IY0H^#[20``````````````
M````````````O!$````````#``L```````"@`````````P`6``0"````````
M`````!(```!W`@`````````````2````90(`````````````$@```-8"````
M`````````!(```"5`@`````````````B````_`(`````````````$0```(,#
M`````````````!(````0```````````````@````_P$`````````````$@``
M`,$"`````````````!(```#C`0`````````````2````Z0``````````````
M$@```!@#`````````````!$```#/`@`````````````2````30$`````````
M````$@```/D!`````````````!(```"'```````````````2````JP(`````
M````````$@```.0``````````````!(```"]`0`````````````2````E0$`
M````````````$@````8#`````````````!(```#<`0`````````````2````
M00(`````````````$@```#\!`````````````!(```#&```````````````1
M````#0$`````````````$@```&,``````````````!8````X`@``````````
M```2````AP(`````````````$0```'L!`````````````!(```"K`0``````
M```````2````:`$`````````````$@```+D"`````````````!(```#-`0``
M```````````2````=`$`````````````$@```!$"`````````````!(````;
M`0`````````````2`````0``````````````(````"`"`````````````!(`
M``"F`0`````````````2````\@$`````````````$@```(8!````````````
M`!$```!4```````````````2````I`(`````````````$@```)8`````````
M`````!(```#=`@`````````````2````20(`````````````$@```*(`````
M`````````!(````T`0`````````````2````"P(`````````````$@```+("
M`````````````!(```#Z```````````````2````1@``````````````$@``
M`.X``````````````!(```!=`0`````````````2````5P(`````````````
M$@```-,``````````````!(```".`@`````````````2````R`(`````````
M````$@```.L!`````````````!(````G`@`````````````2````=@``````
M````````$@```-0!`````````````!(```"S`0`````````````2````MP``
M````````````$@```"L!`````````````!(````L```````````````@````
M_@(`````````````$0```/0"`````````````!(```#N`@`````````````2
M````Q`$`````````````$@```*`#``!<H````````!``%P",`P``J#D``#P!
M```2``T`Q`,``,0O``#T!@``$@`-`'("``"P%```T`(``!(`#0!2`P``I"$`
M``0````2``T`8P,``$B@````````$``7`%`$``"H(0``D`(``!(`#0".!```
MN#8``/`"```2``T`/`0``$B@````````$``7`*L#```X)```,````!(`#0#1
M`P``$$@``"@!```2``T`Z0,``-1*```$````$0`/`!@$``!<H````````!``
M%P`=!```7*`````````0`!<`2`0``#0@``!<````$@`-`%T$``!4+@``<`$`
M`!(`#0!O!```5"L``*`````2``T`?00``/0K``!T````$@`-`-P#````H```
M`````!``%@"X`P``:"0``*@!```2``T`F`,``$B@````````$``6``X$``!$
MH```!````!$`%@#B`P``@!<````````2``T`A00``'A'``"8````$@`-`-X#
M````H````````"``%@!Q`P``,"X``"0````2``T`GP,``%R@````````$``7
M`/@#``"0(```%`$``!(`#0`R!```.$D``&P!```2``T`)00``!`F``!$!0``
M$@`-``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B
M;&4`7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E
M<FQ?<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L
M;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C
M;VYT97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA3
M7V9L86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO
M8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R
M;%]N97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A
M<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W
M<F%P`%]?<W1A8VM?8VAK7V9A:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S
M=')D=7``8VQO<V5D:7(`;W!E;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`
M<W1R=&]K`'-T<FQE;@!R;61I<@!R96%D`'-T<G-T<@!M:V1I<@!?7W9F<')I
M;G1F7V-H:P!G971P:60`7U]L<W1A=#8T7W1I;64V-`!R96%D;&EN:P!R96%L
M;&]C`%]?<W!R:6YT9E]C:&L`7U]F<')I;G1F7V-H:P!?7VQI8F-?<W1A<G1?
M;6%I;@!?7W-T870V-%]T:6UE-C0`<W1D97)R`&UE;6-H<@!?7V-X85]F:6YA
M;&EZ90!S=')C:'(`;65M8VUP`&UE;7-E=`!O<&5N9&ER`&=E='5I9`!A8V-E
M<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N`&%B;W)T`'-T<FYC
M;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?<W1A8VM?8VAK7V=U
M87)D`&QI8G!E<FPN<V\N-2XS.`!L:6)C+G-O+C8`;&0M;&EN=7@N<V\N,P!P
M87)?8W5R<F5N=%]E>&5C`%]?8G-S7W-T87)T7U\`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7V5D871A`%]?8G-S7V5N9%]?`'!A
M<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`<VAA7W5P9&%T
M90!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`&UY7W!A<E]P;`!?96YD`%]?96YD7U\`<&%R7VEN:71?96YV`'-H
M85]F:6YA;`!?7V)S<U]S=&%R=`!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`'!A<E]D:64`<VAA7VEN:70`
M6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N-`!'3$E"0U\R+C,T````
M```````"``,``P`"``(``@`"``$``@`"``(``@`$``(``0`"``$``@`!``(`
M`@`"``(``@`!``$``0`!``(``@`!``(``0`"``(``@`"``$``0`"``(``@`!
M``$``@`!``(``@`!``$``@`"``$``0`!``$``@`!``(``@`"``,``0`"``(`
M`0`!``$``@`"``(``@`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`1`,``!`````@````
M%&EI#0``!`"D!`````````$``@`Z`P``$`````````"TD98&```#`*X$```0
M````%&EI#0```@"D!````````+R=```7````P)T``!<```#PGP``%P````2@
M```7````%*```!<````8H```%P```""@```7````)*```!<````HH```%P``
M`"R@```7````,*```!<````XH```%P```#R@```7````1*```!<```#(GP``
M%0<``,R?```5"@``T)\``!4/``#4GP``%1$``-B?```5'```W)\``!,>``#@
MGP``%2```.2?```5*0``Z)\``!4M``#LGP``%3<``/2?```500``^)\``!5&
M``#\GP``%4<``-B>```6`P``W)X``!8$``#@G@``%@4``.2>```6!@``Z)X`
M`!8'``#LG@``%@D``/">```6"P``])X``!8,``#XG@``%@T``/R>```6#@``
M`)\``!80```$GP``%A(```B?```6$P``#)\``!84```0GP``%A4``!2?```6
M%@``&)\``!87```<GP``%A@``""?```6&0``))\``!8:```HGP``%AL``"R?
M```6'0``,)\``!8?```TGP``%B$``#B?```6(@``/)\``!8C``!`GP``%B0`
M`$2?```6)0``2)\``!8F``!,GP``%B<``%"?```6*```5)\``!8I``!8GP``
M%BH``%R?```6*P``8)\``!8L``!DGP``%BX``&B?```6+P``;)\``!8P``!P
MGP``%C$``'2?```6,@``>)\``!8S``!\GP``%C0``("?```6-0``A)\``!8V
M``"(GP``%C@``(R?```6.0``D)\``!8Z``"4GP``%CL``)B?```6/```G)\`
M`!8]``"@GP``%CX``*2?```6/P``J)\``!9```"LGP``%D(``+"?```60P``
MM)\``!9$``"XGP``%D4``+R?```62```P)\``!9)``#$GP``%DH```A`+>E_
M`0#K"("]Z`3@+>4$X)_E#N"/X`CPON7TC````,:/X@C*C.+T_+SE`,:/X@C*
MC.+L_+SE`,:/X@C*C.+D_+SE`,:/X@C*C.+<_+SE`,:/X@C*C.+4_+SE`,:/
MX@C*C.+,_+SE`,:/X@C*C.+$_+SE`,:/X@C*C.*\_+SE`,:/X@C*C.*T_+SE
M`,:/X@C*C.*L_+SE`,:/X@C*C.*D_+SE`,:/X@C*C.*<_+SE`,:/X@C*C.*4
M_+SE`,:/X@C*C.*,_+SE`,:/X@C*C.*$_+SE`,:/X@C*C.)\_+SE`,:/X@C*
MC.)T_+SE`,:/X@C*C.)L_+SE`,:/X@C*C.)D_+SE`,:/X@C*C.)<_+SE`,:/
MX@C*C.)4_+SE`,:/X@C*C.),_+SE`,:/X@C*C.)$_+SE`,:/X@C*C.(\_+SE
M`,:/X@C*C.(T_+SE`,:/X@C*C.(L_+SE`,:/X@C*C.(D_+SE`,:/X@C*C.(<
M_+SE`,:/X@C*C.(4_+SE`,:/X@C*C.(,_+SE`,:/X@C*C.($_+SE`,:/X@C*
MC.+\^[SE`,:/X@C*C.+T^[SE`,:/X@C*C.+L^[SE`,:/X@C*C.+D^[SE`,:/
MX@C*C.+<^[SE`,:/X@C*C.+4^[SE`,:/X@C*C.+,^[SE`,:/X@C*C.+$^[SE
M`,:/X@C*C.*\^[SE`,:/X@C*C.*T^[SE`,:/X@C*C.*L^[SE`,:/X@C*C.*D
M^[SE`,:/X@C*C.*<^[SE`,:/X@C*C.*4^[SE`,:/X@C*C.*,^[SE`,:/X@C*
MC.*$^[SE`,:/X@C*C.)\^[SE`,:/X@C*C.)T^[SE`,:/X@C*C.)L^[SE`,:/
MX@C*C.)D^[SE`,:/X@C*C.)<^[SE`,:/X@C*C.)4^[SE`,:/X@C*C.),^[SE
M`,:/X@C*C.)$^[SE`,:/X@C*C.(\^[SE`,:/X@C*C.(T^[SE`,:/X@C*C.(L
M^[SE`,:/X@C*C.(D^[SE`,:/X@C*C.(<^[SE``````'*H.-P0"WI#,!-X,@/
MC.5@PI_E8#*?Y2C03>(,P(_@'`"-Y1@0C>44((WE`S"<YQ@0C>(4((WB'`"-
MXCQ"G^4`,)/E)#"-Y0`PH..?___K+"*?Y01`C^`H,I_E`B"4YPP@C>4#,)3G
M`A"@X0,`H.$0,(WE8PT`ZPPRG^4#,)3G`%#3Y0``5>-1```*_#&?Y5H-`.L#
M,)_G'%"=Y0,@D.<$`(7BUC/2Y0<!<.,#,(/C`U"%XM8SPN5B``"*``&@X63_
M_^O($9_ER"&?Y0$0C^`"((_@`,"1Y1Q`G>48$)WE`0!4XP#@D>4`,*#A!`""
MY:0!G^6D(9_E``"/X`(@C^``X(/E`1"#Z0P@@^54``#:!`!!X@S`@^($`8#@
M!."QY03@K.4!`%#A^___&@-`A.(`$*#C:&&?Y0`0C>4$$8/G8!&?Y09@C^`,
M`);E!2"@X0$0C^!^___K``!0XRD```I$49_E(&"-X@50C^`,`)7E*?__ZP80
MH.$`0*#A+`&?Y0``C^"K``#K``!0XR````H<,9_E`S"/X`P`D^4,___K9?__
MZPPAG^7,,)_E`B"/X`,PDN<`()/E)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB
M<("]Z!G__^O<()_E`B"/X```4.,,`(+E'P``"O+^_^O(,)_E`0T`ZP,PG^<#
M,)#GOE;#Y:#__^H,`);E;O__Z]+__^H(`)7E``!0XP$```JT"`#KV?__ZI0`
MG^4&$*#A``"/X'\``.L``%#C"`"%Y=+__PKU___J>#"?Y7@`G^4#,)3G``"/
MX`,0H.$,,(WE*?__ZP1`H..P___J`0"@XQ#__^O<_O_K^(D```0!``#`B0``
M(`$``"@!```,`0``D(H``,"*``#$B@``V#@``-@X``!0B@``?`D``"R*``#T
M-0```(H``&B(``"XB0``+(D``.`T```<`0``O#8```"PH.,`X*#C!!"=Y`T@
MH.$$("WE!``MY1R@G^48,(_B`Z"*X``PH.,$,"WE#`"?Y0``FN>._O_K-?__
MZQ"'```D`0``%#"?Y10@G^4#,(_@`B"3YP``4N,>_R\!V_[_ZOB&```8`0``
M+`"?Y2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_+P$8()_E`C"3YP``4^,>
M_R\!$_\OX5"(``!,B```Q(8````!```X`)_E.#"?Y0``C^`#,(_@`#!#X*,?
MH.%#$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G``!3XQ[_+P$3_R_A#(@`
M``B(``!TA@``+`$``$PPG^5,()_E`S"/X``PT^4"((_@``!3XQ[_+Q$X,)_E
M$$`MZ0,PDN<``%/C`@``"B@PG^4#`)_G5/[_Z\K__^L<,)_E`2"@XP,PC^``
M(,/E$("]Z+R'```XA@``_````$R'``!\AP``T/__Z@'*H./P1RWI#,!-X.`/
MC.7(,)_E`(!0X@,PC^`K```*O""?Y0(PD^<`D)/E``!9XR@```H`4-CE`7"@
MX0``5>,]`%43`5"@$P!0H`,1```:`$"9Y0``5.,,```*"6"@X04@H.$($*#A
M!`"@X<O^_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4``%3C\___&@0`H.'P
MA[WH"%"@X0$P]>4``%/C/0!3$_O__QH(4$7@YO__Z@E@1N`!4(7B1F&@X05`
MA.`$`*#A`&"'Y?"'O>@(0*#A[?__Z@E`H.'K___JQ(4``#`!```!RJ#C$$`M
MZ0S`3>"`#XSEC""?Y8PPG^4"((_@>-!-X@,PDN<-$*#A`$"@X0`PD^5T,(WE
M`#"@XX_^_^L``%#C``"@$P0``!H0,)WE#SH#X@H*4^,!"5,3"@``"D@@G^5`
M,)_E`B"/X`,PDN<`()/E=#"=Y0(@,^``,*#C!P``&GC0C>(0@+WH`A"@XP0`
MH.%S_O_K$`]OX:`"H.'N___J"?[_Z]R$```$`0``D(0```'*H./P0"WI#,!-
MX&@/C.5<(9_E7#&?Y0(@C^`#,)+GA-!-X@!@4.(`,)/E?#"-Y0`PH.,"```*
M`##6Y0``4^,*```:,"&?Y2@QG^4"((_@`S"2YP`@D^5\,)WE`B`SX``PH.-!
M```:A-"-XO"`O>@'_O_K`$!0XO'__PH$`*#A5_[_ZP``4.,J```*$S#0Y1-0
M@.(N`%/C`@``&@$PU>4``%/C]/__"A,PT.4N`%/C)0``"@8`H.$-_O_K`'"@
MX04`H.$*_O_K``"'X`(`@.+U_?_KI#"?Y0`@X.,#,(_@`1"@XP10C>4`8(WE
M`'"@X0[^_^L($(WB!P"@X9G]_^L!`'#C!P"@X0,```H8,)WE#SH#X@$)4^,2
M```*Q/W_ZP<`H.&G_?_K!`"@X2S^_^L``%#CU/__&@0`H.$W_O_K!@"@X:7]
M_^N]___J`3#5Y2X`4^/6__\:`C#5Y0``4^/%__\*TO__ZJ3__^OK___JJ?W_
MZRR$```$`0``^(,```0P```!RJ#C\$<MZ0S`3>#8#XSE`##1Y1`BG^4]`%/C
M##*?Y0(@C^`!0*#A`S"2YP%`@0((T$WB`%"@X00`H.$`,)/E!#"-Y0`PH./(
M_?_K#1"@X=R!G^4(@(_@`&"@X04`H.$?___K`)!0XD````J__?_K``!6X3<`
M`)JX,9_E`'"=Y0.`F.<'<:#A`##5Y0``4^,]`%,3`3"@$P`PH`,%```*!3"@
MX0$@\^4``%+C/0!2$_O__QH%,$/@`@"&X@,`@.``8)CEE_W_ZP``4.,'`(;G
M%0``"@`@F.4%`*#A`3#0Y`<0DN<]`%/C``!3$P`PP>4&```*`2"!X@$PT.0"
M$*#A/0!3XP``4Q,!,,+D^?__&CTPH.,!(*#A`##!Y0$PU.0!,.+E``!3X_O_
M_QH((9_E^#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XS4``!H(T(WB\(>]
MZ`&02>(!,-3D`3#IY0``4^/[__\:[O__ZL`PG^4#@)CG`'"8Y0`PE^4``%/C
M)```"@<PH.$$(+/E"1"@X0``4N,!D(GB^O__&@,0@>(!$:#AD#"?Y0,PC^``
M()/E``!2XP\``!H!(*#C`0"@X0`@@^56_?_K`*!0XM7__PH'$*#A"7&@X0<@
MH.$4_?_K`*"(Y0`PH.,`D(WE`9")X@DQBN>B___J!P"@X2W]_^L``%#C`*"@
MX0``B.7%__\*"7&@X?+__^H#D*#A"!"@X]___^H:_?_KH((```0!``!L@@``
M,`$``(R!``"4@@```<J@X_!!+>D,P$W@``",Y2``#.4!<*#A`!&?Y0`QG^4!
MVDWB"-!-X@$0C^`#,)'G`&"@X0$*C>($`(#B`#"3Y0`P@.4`,*#CV`"?Y02`
MC>+4()_E``"/X`@0H.$._?_K`$!0X@<``-H(4(WB`3!$X@/`A>`$(%SE``!2
MXQ<``!H``%/C%```&J`PG^7U"@#K`S"?YP<@H.$#`)#G!A"@X?K\_^N(()_E
M=#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C$@``&@':C>((
MT(WB\(&]Z`-`H.$$(*#A+Q"@XP@`H.$[_?_K``!0X^/__PHX,)_EV0H`ZP,P
MG^<((*#A`P"0YP80H.$$,*#A0_W_Z^'__^K,_/_K5(````0!``#,+```_P\`
M`/R```#0?P``C(````'*H.,00"WI#,!-X.@/C.5T$)_E=#"?Y0$0C^!P()_E
M$-!-X@,PD><,,(WE`B"?YV`PG^5@$)_ENPH`ZP,PC^``0*#A`1"/X`(`D.<,
M()WE^_S_ZT0`G^5$,)_E``"?YT`@G^5`$)_E`S"/X`#`H.,``)3G`B"/X`$0
MC^`($(WH!/W_ZQ#0C>(0@+WH*'\```@!```D@```8&P``+`K``#T?P``D"X`
M`+@6``"8*P``$$`MZ9P*`.LX0)_E.""?Y01`C^`T,)_E"-!-X@(@E.<$((WE
M`S"?YR00G^4#`)#G(#"?Y0$0C^`#,(_@"-"-XA!`O>C2_/_J@'X```@!``!\
M?P``$"L``+1K```!RJ#C<$`MZ0S`3>```(SE`<I,X@``C.4H``SEV""?Y=@P
MG^4"VDWB&-!-X@(@C^`#,)+G`AJ-XA00@>(`,)/E`#"!Y0`PH..?_/_KL,"?
MY;`PG^4,P(_@#$"-X@%JC>*D()_E`S"/X`$0H.,08(;B`1"-Z`0`H.&H_/_K
M!`"@X0$JH.,&$*#A<?S_ZP!`4.(`4*"S"```N@$`A.)^_/_K`%!0X@0```H$
M(*#A!A"@X4/\_^L`,*#C!##%YTP@G^4X,)_E`B"/X`(:C>(#,)+G%!"!X@`@
MD^4`,)'E`B`SX``PH.,#```:!0"@X0+:C>(8T(WB<("]Z$/\_^L(?@``!`$`
M`-0J``"X*@```1```'!]``"Y___J`<J@X_!/+>D,P$W@``",Y;``#.5$(I_E
M1#*?Y4+=3>(,T$WB`B"/X`!@H.$T`I_E`S"2YT+-C>(0@(WB`4"@X0``C^`(
M$*#A!,",X@`PD^4`,(SE`#"@X[C]_^LO$*#C`%"@X08`H.%=_/_K``!0XQ(`
M``KP`9_E!A"@X0``C^!U_O_K!@"@X>`AG^70,9_E`B"/X$(=C>(#,)+G!!"!
MX@`@D^4`,)'E`B`SX``PH.-I```:0MV-X@S0C>+PC[WH!`"@X0?\_^ND$9_E
M`1"/X'#\_^L`0%#BY?__"@`PU.60D9_EB*"-X@``4^,)D(_@!'!*XCL```H`
M`%7C!```"@00H.$%`*#ATOO_ZP``4.,K```*!`"@X2O\_^L!,$#B`S"$X`,`
M5.$`L*#A`#"$,``0H#,!`(0R`P``.@@``.H#`%#A`!##Y0(```H!('/E+P!2
MX_G__PH$`*#A&OS_ZP"PH.$&`*#A%_S_ZPL`@.`!`(#B`0I0X[W__RKX`)_E
M"3"@X0``C^`!*J#C`1"@XT$`C>D`0(WE!P"@X1G\_^L($*#A!P"@X:3[_^L`
M`%#C`P``&F@P&N4/.@/B`@E3XQ4```JT$)_E``"@XP$0C^`P_/_K`$!0XJ7_
M_PH`,-3E``!3X\/__QH``%7C%@``"@`PU>4N`%/C`P``"H!`G^4!L*#C!$"/
MX-7__^H!,-7E``!3X^K__PKW___J`1"@XP<`H.$8_/_K``!0X^3__QI0`)_E
M!Q"@X0``C^`&_O_K!P"@X:?[_^N.___J.$"?Y0&PH.,$0(_@P?__ZJ3[_^OX
M?```!`$``-@I``"H*0``C'P``&@I``!,*0``O"@``&@H```0*```["<``,`G
M```!RJ#C$$`MZ0S`3>#X#XSE+Q"@XP!`H.$`_/_K``!0XP%`@!($`*#A$$"]
MZ(G[_^H!RJ#C<$`MZ0S`3>```(SE&``,Y7`AG^5P,9_E`=I-X@(@C^`(T$WB
M`1J-X@,PDN<`8%#B!!"!X@`PD^4`,('E`#"@XR\```H`,-;E``!3XRP```JL
M^__K`2"`X@$*4N,`0*#A.```B@10C>(&$*#A!0"@X5S[_^L!,$3B`S"%X`4`
M4^$'``":`!"@XP(``.H%`%/A`1##Y0(```H!(%/D+P!2X_G__PHO$*#C!0"@
MX<[[_^L``%#C)0``"@4`4.$`,*"#`##`A04`H.%5^__KO""?Y;0PG^4"((_@
M`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XR(``!H!VHWB"-"-XG"`O>B(
M()_E?#"?Y0(@C^`!&HWB`S"2YP00@>(`()/E`#"1Y0(@,^``,*#C%```&F``
MG^4``(_@`=J-X@C0C>)P0+WH-OO_Z@``H./>___J1""?Y3`PG^4"((_@`1J-
MX@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@XR``GP4``(\`[/__"BG[_^L\>@``
M!`$``(1Y``!,>0``'"8```!Y``#4)0```<J@XW!`+>D,P$W@Z`^,Y<0DG^7$
M-)_E`B"/X,!DG^4#,)+G"-!-XKA4G^4&8(_@#4"@X0`PD^4$,(WE`#"@XP50
MC^`$$*#A!@"@X:'\_^L``%#C#@``"HPTG^4``)WE`S"5YP`0D^4`,8'@!""3
MY0`A@><``%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZE1DG^4&8(_@
M!!"@X08`H.&+_/_K``!0XPX```HT-)_E``"=Y0,PE><`$)/E`#&!X`0@D^4`
M(8'G``!2X_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^H`9)_E!F"/X`00
MH.$&`*#A=?S_ZP``4.,.```*W#.?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!
MYP``4N/Q__\*!#"#X@0@D^4$((/D``!2X_O__QKK___JK&.?Y09@C^`$$*#A
M!@"@X5_\_^L``%#C#@``"H0SG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><`
M`%+C\?__"@0P@^($()/E!""#Y```4N/[__\:Z___ZEACG^4&8(_@!!"@X08`
MH.%)_/_K``!0XPX```HL,Y_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2
MX_'__PH$,(/B!""3Y00@@^0``%+C^___&NO__^H$8Y_E!F"/X`00H.$&`*#A
M,_S_ZP``4.,.```*U#*?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q
M__\*!#"#X@0@D^4$((/D``!2X_O__QKK___JL&*?Y09@C^`$$*#A!@"@X1W\
M_^L``%#C#@``"GPRG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__
M"@0P@^($()/E!""#Y```4N/[__\:Z___ZEQBG^4&8(_@!!"@X08`H.$'_/_K
M``!0XPX```HD,I_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$
M,(/B!""3Y00@@^0``%+C^___&NO__^H(8I_E!F"/X`00H.$&`*#A\?O_ZP``
M4.,.```*S#&?Y0``G>4#,)7G`!"3Y0`Q@>`$()/E`"&!YP``4N/Q__\*!#"#
MX@0@D^4$((/D``!2X_O__QKK___JM&&?Y09@C^`$$*#A!@"@X=O[_^L``%#C
M#@``"G0QG^4``)WE`S"5YP`0D^4`,8'@!""3Y0`A@><``%+C\?__"@0P@^($
M()/E!""#Y```4N/[__\:Z___ZF!AG^4&8(_@!!"@X08`H.'%^__K``!0XPX`
M``H<,9_E``"=Y0,PE><`$)/E`#&!X`0@D^4`(8'G``!2X_'__PH$,(/B!""3
MY00@@^0``%+C^___&NO__^H,`9_E!!"@X0``C^"P^__K`!!0X@(```KX`)_E
M``"/X'+\_^OP`)_E!!"@X0``C^"G^__K`!!0X@(```K<`)_E``"/X&G\_^O4
M`)_E!!"@X0``C^">^__K`!!0XA(```K``)_E``"/X&#\_^NX()_E9#"?Y0(@
MC^`#,)+G`""3Y00PG>4"(#/@`#"@XQ```!J8$)_EF`"?Y0$0C^```(_@"-"-
MXG!`O>A0_/_JA`"?Y000H.$``(_@A?O_ZP`04.+I__\*<`"?Y0``C^!'_/_K
MY?__ZNOY_^N<>```!`$``+`E``!T>```,`$``%`E````)0``M"0``&0D```<
M)```8",``'@C```L(P``X"(```PB```X(@``#"(``"@B```H(@``)"(``$@A
M```\=````"(``&0A``#0(0``5"$```'*H.,$X"WE#,!-X/`/C.5X()_E>#"?
MY0(@C^!T`)_E#-!-X@,PDN<``(_@#1"@X0`PD^4$,(WE`#"@XU3[_^L``%#C
M!0``"@``T.4``%#C,`!0$P$`H`,``*`3`0`@XC0@G^4H,)_E`B"/X`,PDN<`
M()/E!#"=Y0(@,^``,*#C`0``&@S0C>($\)WDK?G_ZUAS```$`0``M"````AS
M```!RJ#C#P`MZ03@+>4,P$W@\`^,Y4@`G^5($)_E``"/X`$0D.=`P)_E#-!-
MXCP@G^4,P(_@`!"1Y000C>4`$*#C%#"-X@`PC>4"$)SG$""=Y0``D>4!$*#C
MN?G_Z_\`H./#^?_KM'(```0!``"@<@``%`$```#`H./P1RWI`>B@XPS`3>`.
MX$S@`<I,X@``C.4.`%SA^___&C@`#N4!V$WB&-!-X@(0H.-PP9_E`!"-Y6P1
MG^4,P(_@`1"<YP'HC>(`(*#C`#"@XP`0D>44$([E`!"@XQ3@CN(`@*#AB?G_
MZP%@4.(`<,'BQR^@X<<_)N`",%/@`SB@X2,XH.$","/@`C!3X`(@PN`#8%;@
M`G#'X```5^,W``"Z")&?Y0Q0C>(`$*#C!B"@X0<PH.$(`*#A`!"-Y7/Y_^L!
M`''C`0!P`S(```H)(*#A!1"@X0@`H.$V^?_K`0!PXRD```H'`%#C'P``F@@`
M0.(`0)7@'```*K2@G^4*H(_@`@``Z@%`1.(%`%3A%@``.@@@H.,*$*#A!`"@
MX3KY_^L``%#C]O__&@5`1.`&`)3@Q!^GX'P@G^5L,)_E`B"/X`'(C>(#,)+G
M%,",X@`@D^4`,)SE`B`SX``PH.,0```:`=B-XAC0C>+PA[WH`6A6X@!PQ^(!
M`'?C`0AV`\G__QH``.#C`!"@X>G__^HH`)_E``"/X'O__^L@`)_E``"/X'C_
M_^LA^?_K''(```0!```(``$`F'(``!QQ``#$'@``J!X```'*H.,00"WI#,!-
MX/@/C.7Z^/_K\_C_ZP``4.,``)`5$("]Z`'*H./P0"WI#,!-X-`/C.4T(9_E
M-&&?Y30QG^4"((_@'-!-X@,PDN<&8(_@`%"@X1`0C>(&`*#A`#"3Y10PC>4`
M,*#CDOK_ZP!`4.("```*`##4Y0``4^,.```:]""?Y>PPG^4"((_@`S"2YP`@
MD^44,)WE`B`SX``PH.,Q```:U`"?Y040H.$``(_@'-"-XO!`O>A%^__J!1"@
MX;GX_^L``%#C"@``"K`@G^6@,)_E`B"/X`,PDN<`()/E%#"=Y0(@,^``,*#C
M'@``&AS0C>+P@+WH!0"@X1#Y_^L`<*#A!`"@X0WY_^L``(?@`@"`XOCX_^MH
M,)_E`"#@XP,PC^`8`(WI7#"?Y0$0H.,#,(_@`%"-Y0!PH.$/^?_K2""?Y2PP
MG^4"((_@`S"2YP`@D^44,)WE`B`SX``PH.,'$*`!!@"@`=#__PJ^^/_K5'``
M`%`>```$`0``#'```/`=``#`;P``C!P``(`<``!,;P```<J@X_!/+>D,P$W@
MX`Z,Y5#&G^4`H*#A#,"/X`PPC.('`)/H_-!-XI!PC>('`(?H-":?Y30VG^4"
M((_@`S"2YQA@C.(`,)/E]#"-Y0`PH.,/`+;HJ$"-X@3@H.$/`*[H`P"6Z##`
MC.(#`([H!P"<Z)Q0C>('`(7H]`6?Y2"`C>(``(_@"!"@X27Z_^ODM9_E"["/
MX`!@4.("```*`##6Y0``4^,8`0`:;_C_ZVCX_^L``%#C>@``"@!@D.4``%;C
M=P``"@8`H.&X^/_K@`"@X0$`@.*C^/_K`!#6Y0``4>,`4*#A'`"-Y0L```J(
ME9_E"9"/X`4`H.$`$(WE"3"@X0$0H.,`(.#CM_C_ZP$0]N4"4(7B``!1X_7_
M_QI<!9_E``"/X`(``.H$`+3E``!0XPT```H($*#A^?G_ZP!04.+X__\*`##5
MY0``4^/U__\*+?K_ZP``4./R__\*!0"@X5GX_^L`0%#B#0``&@1`E^0``%3C
M"@``"@`PU.4``%/CT```"@0`H.$?^O_K``!0X_7__PH$`*#A2_C_ZP!`4.+Q
M__\*!`"@X8#X_^L<8)WE`'"@X08`H.%\^/_K`'"'X`%[A^($<(?B!P"@X67X
M_^NL-)_E`"#@XP,PC^`(,(WEH#2?Y0$0H.,#,(_@!#"-Y90TG^4,8(WE`S"/
MX`!`C>4`4*#A>/C_ZP<=H.,%`*#A?OC_ZP$`<.,#```:;_C_ZP`0D.41`%'C
MK```&@@0H.$%`*#AD_C_ZP!@4.(M```*2"2?Y0`PFN4"$)OG0"2?Y0``D>4"
M((_@`1"@XP!0C>5Y^/_K`'"@XR@DG^7\,Y_E`B"/X`,PDN<`()/E]#"=Y0(@
M,^``,*#C\@``&@<`H.'\T(WB\(^]Z`OX_^L`8%#BB@``&@0`E>0``%#C"0``
M"@@0H.&:^?_K`#!0XOC__PH`,-/E``!3X_+__QH$`)7D``!0X_7__QH-`*#C
M(?C_Z[1CG^53$*#C!F"/X`!0H.$<`(WE?/__ZC`PG>4/.@/B`0E3X\W__QHX
M0)WEUO?_ZP``5.')__\:,#"=Y8,[H.&C.Z#A!PU3X\3__QH'`*#A#/C_ZP@0
MH.$`<*#A7`.?Y0``C^!V^?_K`!!0XGP```H``)KEHOO_ZP"04.)X```*"0"@
MX1'X_^L#`%#C`$"@X0P``)HH$Y_E!`!`X@``B>`!$(_@K/?_ZP``4.,%```:
M!`!4XZ````H$0(G@!3!4Y2\`4^.<```*^`*?Y0@0H.$``(_@6OG_ZP``4.,#
M```*`##0Y3``4^,``%,3!```&@`0H.,)`*#AW_?_ZP!`4.)9```:P!*?Y<`"
MG^4!$(_@``"/X!'Z_^OF]__KL#*?Y;`BG^4#,(_@##"-Y:@RG^4"((_@I**?
MY:22G^6D@I_E!""-Y0,PC^``(.#C`1"@XP!0C>4*H(_@"9"/X`B`C^`(`(WE
M!P"@X>?W_^L.``#JXO?_ZP`PD.41`%/C$```&LSW_^L!$*#C`6"&X`HPH.$$
M(*#A$)"-Y0Q@C>4`P*#A(!&-Z`<`H.'7]__K!QV@XP<`H.'=]__K`0!PXP!`
MH.'J__\*!0"@X77W_^L8`I_E!Q"@X0``C^#@^?_K!P"@X7+^_^MG___J`T"@
MX33__^JV]__K@`"@X0$`@.+\_O_JJ"&?Y0`PFN4"`)OGW"&?Y0``D.4"((_@
M!!"-Y0!0C>4!$*#CT/?_ZU7__^I?_O_KO"&?Y50QG^4"((_@`S"2YP`@D^7T
M,)WE`B`SX``PH.-(```:!@"@X?S0C>+P3[WH8??_Z@"0FN6$___JU/W_ZP"0
M4>(`@*#AH?__N@H@4.(`H*#C`##)X@0`H.'`L(WB`*"-Y6_W_^L&(*#C"Q"@
MX00`H.$U]__K!@!0XS(``!I`,9_EP""=Y0,`4N&0__\:M"#;X3`QG^4#`%+A
MC/__&C(@6.(`,,GB!`"@X<A@C>(`H(WE6_?_ZR@@H.,$`*#A!A"@X2'W_^LH
M`%#C'@``&O@PG^4`(.#C`S"/X`PPC>7L,)_E`1"@XP,PC^!(`(WIX#"?Y0<`
MH.$#,(_@`%"-Y?"@S>5T]__KH?__Z@1`FN4``%3C7___"@0`H.%?]__K`P!0
MXUO__YJL$)_E!`!`X@``A.`!$(_@^_;_ZP``4.,$D*`!4___ZA[W_^N,`)_E
M``"/X'']_^LD<```R&X```0!``!\&P``<&X``#`<``"8&P``7!L``#P:```P
M&P``%`$``"0;``"0;```,!H``(P:``!4&@``O!@``/P8``!\&```M!H``!08
M``#<&0``W!D``(`:``#H%P``2!<``$@8``#H:0```$-!0TA%``#0&```+!8`
M`.@7``"8%P``A!<```'*H.-P0"WI#,!-X.@/C.5X$I_E>"*?Y0$0C^`"()'G
M"-!-XFPRG^4`()+E!""-Y0`@H.,#,)_G[@0`ZP-`D.=4`I_E:##4Y0U0H.$`
M`(_@:3#$Y040H.%T^/_K``!0XP(```H`,-#E,0!3XVT```JX^__K)#*?Y=X$
M`.L#,)_G`T"0YQ@2G^4$`*#A`1"/X`,PH.,!(*#C^_;_ZP!`4.(.```*$""4
MY?@QG^4`$)+E`S"?Y_`AG^7.!`#K`B"/X`!@H.$#`)#GU/;_ZQ`PE.4`$)/E
M"#"1Y0$%$^-=```:R#&?Y<@1G^4#,)_GP00`ZP$@H.,`8*#A`1"/X`,`D.<#
M,*#CX/;_ZP!`4.(+```*H`&?Y040H.$``(_@0_C_ZP`@4.)#```*C#&?Y1`0
ME.4#,)_G`!"1Y0,`EN>W]O_K>#&?Y:L$`.L#,)_G<!&?Y0-@D.<`0*#A`1"/
MX`$@H.,&`*#AW?;_ZU@AG^4"((_@`!"@X08`H.&H]O_K2#&?Y4@!G^4#,)_G
M`""@XP,PE.<%$*#A``"/X&D@P^4C^/_K+%&?Y050C^```%#C`$"@X0@`A>42
M```*!QV@XP0`H.'5]O_K`2"`XA$`4.,!`%(3`#"@X24``(KX()_EL#"?Y0(@
MC^`#,)+G`""3Y00PG>4"(#/@`#"@XQL``!H(T(WB<("]Z`0`E>6__?_K``!0
MXP!`H.$(`(7EYO__&K@`G^4``(_@MO;_ZP$PT.4``%/CD___"HW__^J@,)_E
M$""4Y0,PC^`$,)/E``"2Y0`0D^5.^?_KN?__ZH0PG^4#,)_G`P"6Y[7V_^N<
M___J7/;_ZW`@G^5P`)_E`B"/X`0@DN4``(_@`!"2Y00@H.&<]O_K]&<```0!
M``#H:```$!4``*!H``"D%@``;&@``'@6```T:```1!8``/P3``#L9P``U&<`
M`.@5``#L%0``F&<``'03``#H9P``+&8``$`5``!,9P``P&8``!1G```$%0``
M`<J@XS!`+>D,P$W@Z`^,Y0PAG^4,,9_E`B"/X`!`H.$$`9_E`S"2YPS03>(-
M$*#A``"/X``PD^4$,(WE`#"@X[[W_^L`,%#B"@``"@`PT^4``%/C,`!3$P$P
MH`,`,*`3`3`CX@``5.,`,*`#`3`#$@``4^,*```:L""?Y:0PG^4"((_@`S"2
MYP`@D^4$,)WE`B`SX``PH.,@```:#-"-XC"`O>@`,-3E``!3X_'__PH$`*#A
M@?K_ZR\0H.,`4*#A>O;_ZP``4.,!4(`2!0"@X03V_^M8$)_E!""@XP$0C^!^
M]O_K``!0X^+__QI$()_E,#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XP,`
M`!H$`*#A#-"-XC!`O>CM]__J\_7_ZP1E```$`0``6!(``)QD``!T$@``*&0`
M```````!RJ#C\$\MZ0S`3>!`#8SE7.R?Y5P\G^4.X(_@I]]-X@,PGN<0((WB
M`!"@X4#`@.*`4(#B`#"3Y90RC>4`,*#C`@"@X0!`H.,$8!SE"'`<Y28TH.%G
MZ"?@_SP#XB8\@^$NY*#A!H2@X08\@^'_[,[C_V@(X@C`C.)GY"[@!C"#X04`
M7.$`X(#E!$"`Y0@P@.4,0(#E$`"`XNK__QJ"/X+B!#"-Y8@PG>48X(WB'*"=
MY0@0C>5X@)WE?""=Y1BPG>6`<)WEA&"=Y8S`G>404)WE%$"=Y0X`H.$#$*#A
M#."-Y0"@C>4!``#J";"@X0`PC>4!,*#A/."0Y3@0D.4(D+#E`*"@XPD0(>`(
M$"'@!X"@X0-PH.$$,)#E!1`AX`/@+N`"X"[@!.`NX`8@H.$,8*#AH<^@X8[`
MC.$!$)'@#!"!X03`G>4`0)WE``!<X0M0H.$*P*#A=*"`Y7`0@.7A__\:"!"=
MY0S@G>4`@)'E"#N?Y0$(D>D((![E($"1Y:AMH.$0<)'E&)"1Y0,@DN"`8H;A
M!""2X(ABAN$,P)'E`F"6X`D@)^`K4:#A"R`"X`D@(N`,7X7A`F"6X`M?A>$8
M()WE*,&@X0#/C.$%`"?@`R"2X`@``.`)()+@!P`@X`C/C.$``)+@""">Y0Q`
M)>`#()+@!D`$X`5`).`'()+@Y@V`X`0@DN#@38+@$"">Y0,@DN`%()+@9E$L
MX`!0!>`,4"7@!2"2X!A0GN5@`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@
M!<"<X.)=C.`@P)[E`\"<X&;!C.!D82#@`F`&X`!@)N`&P)S@*&">Y6(AH.$#
M8);@``"6X&1A(N`%8`;@9&$FX.7-C.`&`)#@[&V`X#``GN4#`)#@9`&`X&5!
M(N`,0`3@`D`DX`0`D.`X0)[E;,&@X0-`E.`"()3@94$LX`9`!.!E023@Y@V`
MX`0@DN#@38+@0"">Y0,@DN!E(8+@9E$LX`!0!>`,4"7@!2"2X$A0GN5@`:#A
M`U"5X`S`E>!F42#@!%`%X&91)>#D+8+@!<"<X.)=C.!0P)[E`\"<X&;!C.!D
M82#@`F`&X`!@)N`&P)S@6&">Y6(AH.$#8);@``"6X&1A(N`%8`;@9&$FX.7-
MC.`&`)#@[&V`X&``GN4#`)#@9`&`X&5!(N`,0`3@`D`DX`0`D.!H0)[E;,&@
MX0-`E.`"()3@94$LX`9`!.!E023@Y@V`X`0@DN#@38+@<"">Y0,@DN!E(8+@
M9E$LX`!0!>`,4"7@!2"2X'A0GN5@`:#A`U"5X`S`E>!F42#@!%`%X&91)>#D
M+8+@!<"<X.)=C."`P)[E`\"<X&;!C.!D82#@`F`&X`!@)N`&P)S@Y6V,X(C`
MGN5B(:#A`\"<X```G.!DP2+@!<`,X&3!+.`,`)#@YLV`X)``GN4#,)#@90$B
MX`8``.`"`"#@9#&#X``PD^#LK8/@F`">Y2PXG^5F8:#A`P"0X*!`GN4"()#@
M90$FX`P`(.``()+@`P"4X&4!@.#J38+@J%">Y6PA)N`*("+@`@"0X&HAH.$#
M4)7@L*">Y090E>!L82+@!&`FX.0-@.`&4)7@`V":X&QAAN"XH)[EX,V%X&11
M(N``4"7@!6"6X&`!H.$#4)K@`E"5X,"@GN7L+8;@9&$@X`Q@)N`&4)7@`V":
MX&1AAN#(H)[E;$$@X`)`).#B787@!&"6X&(AH.$#0)K@``"4X-"@GN5L02+@
M!4`DX`1`D.`#`)K@Y6V&X-B@GN5L`8#@9<$BX`;`+.#F383@#`"0X&9AH.$#
MP)K@`B"<X."@GN5EP2;@!,`LX`S`DN`#()K@Y`V`X.B@GN5E(8+@9%$FX`!0
M)>#@S8S@!2"2X&`!H.$#4)K@!E"5X/B@GN7P8)[E9.$@X`S@+N#L+8+@#N"5
MX.)=CN`#8);@;.$@X&1!AN`"X"[@#N"4X&(AH.$#0)K@`$"4X!AAG>5L`2+@
M!0`@X.7MCN```)3@`V"6X.Y-@.!LP8;@90$BX"!AG>4.`"#@``"<X&[AH.$#
M8);@`B"6X&7!+N`H89WE!,`LX.0-@.`,P)+@`R"6X&4A@N`P89WEX%V,X&3!
M+N``P"S@#,"2X&`!H.$#8);@Y2V,X`[@EN!DP2#@.&&=Y07`+.`,P)[@`^"6
MX&3ACN!`89WE94$@X`)`).#BS8S@!.">X&(AH.$#8);@``"6X&5!(N!(89WE
M#$`DX.SMCN!0H9WE!$"0X`,`EN#L-9_E;&$BX&4!@.`.8";@;E&@X>Y-A.`&
M8)#@;.&%X0,`FN`"`)#@6*&=Y>0MAN`$X`[@;&$%X`;@CN$.X)#@`Z":X&0!
MA>%D807@;,&*X`(``.!@H9WE!@"`X>+MCN`,`)#@8B&@X0/`FN`%P)S@9%&"
MX61A`N!HH9WE#E`%X`90A>'N#8#@#%"5X`.@FN!NP8+A;F$"X&1!BN``P`S@
M<*&=Y0;`C.'@787@!$"<X&`!H.$#P)K@`L"<X.4MA.!N08#A;F$`X'BAG>4%
M0`3@!D"$X0Q`E.`#H)K@9<&`X65A`.!NX8K@`L`,X("AG>4&P(SAXDV$X`[@
MG.!B(:#A`\":X`#`G.#D#8[@9>&"X65A`N"(H9WE!.`.X`;@CN$,X)[@`Z":
MX&3!@N%D80+@95&*X`#`#."0H9WE!L",X>#MCN`%4)S@8`&@X0/`FN`"P)S@
M[BV%X&11@.%D80#@F*&=Y0Y0!>`&4(7A#%"5X`.@FN!NP8#A;F$`X&1!BN`"
MP`S@H*&=Y0;`C.'B787@!$"<X&(AH.$#P)K@`,"<X.4-A.!N08+A;F$"X*BA
MG>4%0`3@!D"$X0Q`E.`#H)K@9<&"X65A`N!NX8K@`,`,X+"AG>4&P(SAX$V$
MX`[@G.!@`:#A`\":X`+`G.#D+8[@9>&`X65A`."XH9WE!.`.X`;@CN$,X)[@
M`Z":X&3!@.%D80#@95&*X`+`#.#`H9WE!L",X>+MCN`%4)S@8B&@X0/`FN``
MP)S@[@V%X&11@N'(H9WE9&$"X`Y0!>`&4(7A#%"5X`.@FN!NP8+A;F$"X&1!
MBN``P`S@T*&=Y0;`C.'@787@!$"<X&`!H.$#P)K@`&"@XP+`G.#E+83@;D&`
MX05`!.`$8('E#&"!Y11@@>4<8('E;F$`X-BAG>4&0(3A#$"4X&7!@.$#H)K@
M96$`X`+`#.!NX8K@!L",X>"AG>7B383@#L"<X&(AH.'D[8S@`Z":X&7!@N%E
M80+@``":X`3`#.#HH9WE!L",X0#`G.`#H)K@9`&"X>@RG^5D80+@95&*X`X`
M`.#PH9WE!@"`X>[-C.`%`)#@;N&@X0-0FN`"4)7@^&&=Y60A+N`,("+@[`V`
MX`(@E>`#8);@X%V"X&1!AN!L(2[@`&*=Y0`@(N`"()3@8`&@X0-`EN`.0)3@
M"&*=Y6SA(.`%X"[@#N"4X`-`EN#E+8+@$&*=Y6Q!A.!EP2#@`L`LX.+MCN`,
MP)3@8B&@X0-`EN``0)3@&&*=Y64!(N`.`"#@[LV,X```E.`#0);@94&$X"!B
MG>7L78#@;@$BX`P`(.```)3@;,&@X0-`EN`"0)3@*&*=Y6XA+.`%("+@Y0V`
MX`(@E.`#8);@X$V"X&[AAN!E(2S@,&*=Y0`@(N`"()[@8`&@X0/@EN`,X)[@
M.&*=Y67!(.`$P"S@Y"V"X`S`GN`#X);@9>&.X$!BG>7B78S@9,$@X`+`+.`,
MP)[@8B&@X0/@EN``X)[@2&*=Y60!(N`%`"#@Y<V,X```GN`#X);@9.&.X%!B
MG>7L38#@90$BX`P`(.```)[@;,&@X0/@EN`"X)[@6&*=Y64A+.`$("+@Y`V`
MX`(@GN`#X);@9>&.X&!BG>7@78+@9"$LX``@(N`"()[@8`&@X0/@EN`,X)[@
M:&*=Y63!(.`%P"S@Y2V"X`S`GN`#X);@9.&.X'!BG>7B38S@9<$@X`+`+.`,
MP)[@8B&@X0/@EN``X)[@>&*=Y64!(N`$`"#@``">X`/@EN#DS8S@9>&.X&1A
M(N"`4IWE#&`FX.P-@.`&X)[@;,&@X0-0E>`"()7@9&$LX(A2G>4`8";@!B"2
MX`,PE>#@[8[@8)&)X`@PD^!@`2S@#@`@X&0Q@^``,)/@[BV"X.(]@^!N<8?@
M"R"2X"``D>48D('E$'"!Y0`P@>4((('E4""?Y3@PG^4"((_@`,"<X`!@H.,@
MP('E)&"!Y0,PDN<`()/EE#*=Y0(@,^``,*#C`0``&J??C>+PC[WHS_+_Z\1C
M```$`0``F7F"6J'KV6[<O!N/UL%BRJ!7```!RJ#C<$`MZ0S`3>#P#XSE@`"@
MX^;R_^M04(_BT$#%X0`@H./P0,#A2%"/XM!`Q>%X((#E^$#`X4!0C^+00,7A
M\$'`X3Q0C^+00,7A^$'`X3A0C^+00,7A\$+`X0!`H.,`4*#C^$+`X?!#P.%P
M@+WH`2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#``````'*
MH./P1RWI#,!-X.`/C.4H,)#E`F"@X8;!@^`L()#E`P!<X0`PH.,"(-/@`%"@
MX3`@D.4!0*#A-!"0Y<8/H.$!```J`2"2X@`0H>(L,(7EICZ@X8`Q@^$",)/@
MH!ZAX'@`E>4HP(7E``!0XSB`A0(P,(7E-!"%Y18``!H_`%;C)@``VD!@1N(F
MDZ#A`7")X@=SA.`$$*#A0""@XP@`H.%G\O_K0$"$X@4`H.&)_/_K!P!4X?;_
M_QH)G6G@"6.&X`8@H.$'$*#A"`"@X5SR_^MX8(7E\(>]Z$!P8.(&`%?A!G"@
MH3B`A>(``(C@!R"@X000H.%2\O_K>#"5Y0,PA^!``%/C>#"%Y?"'O1@%`*#A
M!V!&X`=`A.!N_/_KUO__Z@1PH.'E___J`<J@X_!!+>D,P$W@Z`^,Y2@PD>4!
M0*#A8R@CX#`0D>4B)*#A_RS"XV-T(N!A*"'@HS&@X2(DH.$_,`/B_RS"XV%D
M(N`!$(/B.("$XG\@X.,X`%'C`%"@X0,@R.<]``#:0"!AX@$`B.``$*#CC?+_
MZP0`H.%-_/_K.""@XP`0H.,(`*#AA_+_ZP0`H.%P8(3E='"$Y47\_^L#,-3E
M`##%Y;(PU.$!,,7E`#"4Y00`H.$C-*#A`C#%Y0`PE.4#,,7E"S#4Y00PQ>6Z
M,-3A!3#%Y0@PE.4C-*#A!C#%Y0@PE.4',,7E$S#4Y0@PQ>6R,=3A"3#%Y1`P
ME.4C-*#A"C#%Y1`PE.4+,,7E&S#4Y0PPQ>6Z,=3A#3#%Y1@PE.4C-*#A#C#%
MY1@PE.4/,,7E(S#4Y1`PQ>6R,M3A$3#%Y2`PE.4C-*#A$C#%Y2`PE.43,,7E
M\$&]Z.WQ_^H!`(C@."!AX@`0H.-/\O_KQO__Z@````````````````\*X.,?
M\$#B"#"?Y0,PC^``,)/E]_'_ZD!5```(0"WI"("]Z`$``@`^````00````P`
M``!!````$0```$$````G````00```#8```!!`````P```$$````&````00``
M`!4```!!````#P```$$````.````00```"8```!!````$P```$$````I````
M00````(```!!````&0```$$````*````00````L```!!```````````````E
M<R\E<P```"]P<F]C+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,
M;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE
M`"X```!005)?5$5-4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``
M+P```%!%4DPU3$E"`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!0
M05)?24Y)5$E!3$E:140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%
M0E5'````4$%27T-!0TA%````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/
M0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?
M1TQ/0D%,7T-,14%.`````#$```!L<V5E:R!F86EL960`````<F5A9"!F86EL
M960`3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>``````E<R5S)7,E<P``
M``!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C
M=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y
M('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````<&%R;``````N<&%R`````'-H
M;W)T(')E860``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E
M<W1E;7`M)74M)74E<P`````8````<&5R;``````P````4$%2.CI086-K97(Z
M.E9%4E-)3TX`````,2XP-C(```!5;F%B;&4@=&\@8W)E871E(&-A8VAE(&1I
M<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D
M:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*`````"UE```M+0``55-%
M4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP`````&5V86P@)V5X
M96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO
M="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*
M;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M
M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD
M1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA
M;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*
M<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK
M7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H
M.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I
M>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK
M7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*
M<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'
M24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^
M/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ
M93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`
M=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z
M.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I
M;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E
M<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M
M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@
M;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-
M4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID
M:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@
M,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T
M;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@
M+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE
M;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G
M)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N
M86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B([
M"G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O
M8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"
M14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT
M97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY
M("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?
M<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE
M("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@
M)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\
M3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H
M<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H
M*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*
M34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S
M<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A
M;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S
M92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,[
M"GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H
M)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T
M<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T
M($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D
M;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B
M=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@
M)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R
M(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@
M(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?
M;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?
M<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/
M9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@
M7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T
M+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R
M97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA
M;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL
M;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U
M9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT[
M"B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F
M+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE
M*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY
M("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S
M("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD
M;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM0
M05)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D
M9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A
M=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT
M*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*
M?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C
M?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA
M;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID
M:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D
M;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E
M(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP
M;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R
M="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL
M96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N
M86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS
M92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N
M86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T<RAQ<5M.
M;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@(B1P<F]G
M;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]"FUY($!P
M87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A8VAE7VYA
M;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ92`H
M4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D<W1A<G1?
M<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I
M*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN
M<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@
M=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E
M=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H
M:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM
M>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>
M+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G
M22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-
M)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS
M:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U
M="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E
M)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE
M;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q
M("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T
M(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I
M('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D
M8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G
M?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B
M?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D
M7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*
M;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@
M)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;
M0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H)'II<"!A
M;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD
M;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII9B`H9&5F
M:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R(&]R(&1I
M92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM>2`D8G5F
M.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N;W0@82!P
M87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC;&]S92`D
M<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ3U]2
M1%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q
M<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E
M*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A9&5R+"`D
M<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]615)"051)
M37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A9&5R*0IO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B.B`D(5T[
M"FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO
M9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC
M.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L
M7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X
M="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I
M;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H
M+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*
M?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H
M;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD
M;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%
M("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I
M*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N
M(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D=&@["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D
M9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@96UB
M961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET=&5N(&%S
M("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E5&]&:6QE
M2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D:64@<7%;
M17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF("@D;65T
M85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*?0IE;'-E
M('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@/2!$:6=E
M<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^861D9FEL
M92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D8W1X+3YH
M97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L
M(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<,"(@>"`H
M)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D["B1F:"T^
M<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F9G-E="`]
M("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN="AP86-K
M*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E(&]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D(5T["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&
M:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI
M=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N
M*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z
M("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R;VU&:6QE
M2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+
M*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<')O
M9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@*B`Q,#(T
M*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP+BXN(BD[
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E
M="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM
M96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D
M;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@
M)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA
M;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H
M)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?
M;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@
M>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L
M<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S
M*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M
M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@
M97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D
M*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*
M=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B
M+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)
M9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!=
M"B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*
M<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I
M;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q
M=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N
M;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U
M8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA
M3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U
M:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O
M<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P[
M"G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N
M9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB
M.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*
M<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z
M.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E
M<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R
M('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q
M=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@
M5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R
M;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E
M('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*
M)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@*
M*&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@
M5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U
M;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H
M.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G
M971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I
M;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN
M3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@
M)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\
M?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P
M871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D[
M"FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.
M5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS
M92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q
M6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?
M<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@
M)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP
M0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D
M;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#
M2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D
M8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@
M/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?
M9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.
M?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M
M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0
M?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A
M<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U
M;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN
M86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@[
M"BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H
M("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M
M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA
M;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64[
M"GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]0
M4D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*
M)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[
M4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]
M*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E
M>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[
M4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM
M?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2![
M"G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E
M>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*
M9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?
M9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD
M<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?
M9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D
M:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D
M<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@
M>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H
M:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA
M;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD
M969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I
M;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@
M*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y
M<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'
M3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H
M("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E
M;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!3
M4$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*
M9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0
M($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?
M1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*
M?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.
M?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F
M:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<
M;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`
M24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q
M=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E
M>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA
M:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A
M<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N
M)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE
M(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O
M9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF
M("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?
M15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/
M4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`````$-!0TA%```^````00````P`
M``!!````$0```$$````G````00```#8```!!`````P```$$````&````00``
M`!4```!!````#P```$$````.````00```"8```!!````$P```$$````I````
M00````(```!!````&0```$$````*````00````L```!!``````````````"T
MBO]_`0``````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````#D&```?!@```$````J`P```0```#H#```!````1`,`
M``P```"\$0``#0```,Q*```9````O)T``!L````$````&@```,"=```<````
M!````/7^_V^L`0``!0```"@)```&````F`(```H```"Y!```"P```!`````5
M``````````,```#,G@```@```.`!```4````$0```!<```#<#P``$0````0/
M```2````V````!,````(````'@````@```#[__]O`0``"/[__V^T#@``____
M;P(```#P__]OX@T``/K__V\.````````````````````````````````````
M`````````````````````,2=`````````````,@1``#($0``R!$``,@1``#(
M$0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1
M``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$`
M`,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``
MR!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#(
M$0``R!$``,@1``#($0``R!$``,@1``#($0``R!$``,@1``#($0``R!$`````
M``````````````````````````````````````````````````"P%```````
M``````````````````2@```*4$%2+G!M"@````"P3@``Q$L```````"$3```
MB$P``*1.``#,2P``K$X```````"03@``F$X```````"X3@``1T-#.B`H1&5B
M:6%N(#$S+C(N,"TQ."D@,3,N,BXP`$$J````865A8FD``2`````%-51%``8$
M"`$)`1($$P$4`14!%P,8`1D!&@(`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N
M9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U=&5S````````
M````````````````````````````````````````````````"P````$````"
M````5`$``%0!```3```````````````!`````````!,````'`````@```&@!
M``!H`0``)```````````````!``````````F````!P````(```",`0``C`$`
M`"````````````````0`````````-````/;__V\"````K`$``*P!``#L````
M!0`````````$````!````#X````+`````@```)@"``"8`@``D`8```8````#
M````!````!````!&`````P````(````H"0``*`D``+D$``````````````$`
M````````3@```/___V\"````X@T``.(-``#2````!0`````````"`````@``
M`%L```#^__]O`@```+0.``"T#@``4`````8````"````!`````````!J````
M"0````(````$#P``!`\``-@````%``````````0````(````<P````D```!"
M````W`\``-P/``#@`0``!0```!4````$````"````'P````!````!@```+P1
M``"\$0``#```````````````!`````````!W`````0````8```#($0``R!$`
M`.0"``````````````0````$````@@````$````&````L!0``+`4```<-@``
M```````````0`````````(@````!````!@```,Q*``#,2@``"```````````
M````!`````````".`````0````(```#42@``U$H``/A!``````````````0`
M````````E@````$``'""````S(P``,R,```(````#0`````````$````````
M`*$````!`````@```-2,``#4C```!```````````````!`````````"K````
M#@````,```"\G0``O(T```0```````````````0````$````MP````\````#
M````P)T``,"-```$```````````````$````!````,,````&`````P```,2=
M``#$C0``"`$```8`````````!`````@```#,`````0````,```#,G@``S(X`
M`#0!``````````````0````$````T0````$````#`````*````"0``!(````
M```````````$`````````-<````(`````P```$B@``!(D```%```````````
M````!`````````#<`````0```#``````````2)```!\```````````````$`
M```!````Y0````,``'```````````&>0```K```````````````!````````
I``$````#``````````````"2D```]0```````````````0``````````
